@@ -1,5 +1,4 @@
-// +build darwin dragonfly freebsd !android,linux netbsd openbsd solaris aix
-// +build cgo
+// +build darwin dragonfly freebsd !android,linux netbsd openbsd solaris aix js
 
 package sftp
 
@@ -10,7 +9,7 @@ import (
 
 func fileStatFromInfoOs(fi os.FileInfo, flags *uint32, fileStat *FileStat) {
 	if statt, ok := fi.Sys().(*syscall.Stat_t); ok {
-		*flags |= ssh_FILEXFER_ATTR_UIDGID
+		*flags |= sshFileXferAttrUIDGID
 		fileStat.UID = statt.Uid
 		fileStat.GID = statt.Gid
 	}
