@@ -1,15 +1,13 @@
 package sftp
 
 import (
-	"sync"
-
-	"github.com/stretchr/testify/assert"
-
 	"bytes"
 	"errors"
 	"io"
 	"os"
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 type testHandler struct {
@@ -65,9 +63,9 @@ func testRequest(method string) *Request {
 	var flags uint32
 	switch method {
 	case "Get":
-		flags = flags | ssh_FXF_READ
+		flags = flags | sshFxfRead
 	case "Put":
-		flags = flags | ssh_FXF_WRITE
+		flags = flags | sshFxfWrite
 	}
 	request := &Request{
 		Filepath: "./request_test.go",
@@ -75,7 +73,6 @@ func testRequest(method string) *Request {
 		Attrs:    []byte("foo"),
 		Flags:    flags,
 		Target:   "foo",
-		state:    state{RWMutex: new(sync.RWMutex)},
 	}
 	return request
 }
@@ -118,12 +115,12 @@ func (h *Handlers) returnError(err error) {
 }
 
 func getStatusMsg(p interface{}) string {
-	pkt := p.(sshFxpStatusPacket)
+	pkt := p.(*sshFxpStatusPacket)
 	return pkt.StatusError.msg
 }
 func checkOkStatus(t *testing.T, p interface{}) {
-	pkt := p.(sshFxpStatusPacket)
-	assert.Equal(t, pkt.StatusError.Code, uint32(ssh_FX_OK),
+	pkt := p.(*sshFxpStatusPacket)
+	assert.Equal(t, pkt.StatusError.Code, uint32(sshFxOk),
 		"sshFxpStatusPacket not OK\n", pkt.StatusError.msg)
 }
 
@@ -152,7 +149,7 @@ func TestRequestGet(t *testing.T) {
 	for i, txt := range []string{"file-", "data."} {
 		pkt := &sshFxpReadPacket{ID: uint32(i), Handle: "a",
 			Offset: uint64(i * 5), Len: 5}
-		rpkt := request.call(handlers, pkt)
+		rpkt := request.call(handlers, pkt, nil, 0)
 		dpkt := rpkt.(*sshFxpDataPacket)
 		assert.Equal(t, dpkt.id(), uint32(i))
 		assert.Equal(t, string(dpkt.Data), txt)
@@ -165,8 +162,8 @@ func TestRequestCustomError(t *testing.T) {
 	pkt := fakePacket{myid: 1}
 	cmdErr := errors.New("stat not supported")
 	handlers.returnError(cmdErr)
-	rpkt := request.call(handlers, pkt)
-	assert.Equal(t, rpkt, statusFromError(rpkt, cmdErr))
+	rpkt := request.call(handlers, pkt, nil, 0)
+	assert.Equal(t, rpkt, statusFromError(pkt.myid, cmdErr))
 }
 
 // XXX can't just set method to Get, need to use Open to setup Get/Put
@@ -176,11 +173,11 @@ func TestRequestPut(t *testing.T) {
 	request.state.writerAt, _ = handlers.FilePut.Filewrite(request)
 	pkt := &sshFxpWritePacket{ID: 0, Handle: "a", Offset: 0, Length: 5,
 		Data: []byte("file-")}
-	rpkt := request.call(handlers, pkt)
+	rpkt := request.call(handlers, pkt, nil, 0)
 	checkOkStatus(t, rpkt)
 	pkt = &sshFxpWritePacket{ID: 1, Handle: "a", Offset: 5, Length: 5,
 		Data: []byte("data.")}
-	rpkt = request.call(handlers, pkt)
+	rpkt = request.call(handlers, pkt, nil, 0)
 	checkOkStatus(t, rpkt)
 	assert.Equal(t, "file-data.", handlers.getOutString())
 }
@@ -189,19 +186,19 @@ func TestRequestCmdr(t *testing.T) {
 	handlers := newTestHandlers()
 	request := testRequest("Mkdir")
 	pkt := fakePacket{myid: 1}
-	rpkt := request.call(handlers, pkt)
+	rpkt := request.call(handlers, pkt, nil, 0)
 	checkOkStatus(t, rpkt)
 
 	handlers.returnError(errTest)
-	rpkt = request.call(handlers, pkt)
-	assert.Equal(t, rpkt, statusFromError(rpkt, errTest))
+	rpkt = request.call(handlers, pkt, nil, 0)
+	assert.Equal(t, rpkt, statusFromError(pkt.myid, errTest))
 }
 
 func TestRequestInfoStat(t *testing.T) {
 	handlers := newTestHandlers()
 	request := testRequest("Stat")
 	pkt := fakePacket{myid: 1}
-	rpkt := request.call(handlers, pkt)
+	rpkt := request.call(handlers, pkt, nil, 0)
 	spkt, ok := rpkt.(*sshFxpStatResponse)
 	assert.True(t, ok)
 	assert.Equal(t, spkt.info.Name(), "request_test.go")
@@ -218,16 +215,16 @@ func TestRequestInfoList(t *testing.T) {
 		assert.Equal(t, hpkt.Handle, "1")
 	}
 	pkt = fakePacket{myid: 2}
-	request.call(handlers, pkt)
+	request.call(handlers, pkt, nil, 0)
 }
 func TestRequestInfoReadlink(t *testing.T) {
 	handlers := newTestHandlers()
 	request := testRequest("Readlink")
 	pkt := fakePacket{myid: 1}
-	rpkt := request.call(handlers, pkt)
+	rpkt := request.call(handlers, pkt, nil, 0)
 	npkt, ok := rpkt.(*sshFxpNamePacket)
 	if assert.True(t, ok) {
-		assert.IsType(t, sshFxpNameAttr{}, npkt.NameAttrs[0])
+		assert.IsType(t, &sshFxpNameAttr{}, npkt.NameAttrs[0])
 		assert.Equal(t, npkt.NameAttrs[0].Name, "request_test.go")
 	}
 }
@@ -237,7 +234,7 @@ func TestOpendirHandleReuse(t *testing.T) {
 	request := testRequest("Stat")
 	request.handle = "1"
 	pkt := fakePacket{myid: 1}
-	rpkt := request.call(handlers, pkt)
+	rpkt := request.call(handlers, pkt, nil, 0)
 	assert.IsType(t, &sshFxpStatResponse{}, rpkt)
 
 	request.Method = "List"
@@ -247,6 +244,6 @@ func TestOpendirHandleReuse(t *testing.T) {
 		hpkt := rpkt.(*sshFxpHandlePacket)
 		assert.Equal(t, hpkt.Handle, "1")
 	}
-	rpkt = request.call(handlers, pkt)
+	rpkt = request.call(handlers, pkt, nil, 0)
 	assert.IsType(t, &sshFxpNamePacket{}, rpkt)
 }
